@@ -62,13 +62,12 @@ class DataFrameSummary(object):
         raise KeyError(column)
 
     def _get_pairplot(self,data):
-        self.data=data
-        for i in self.data.columns:
-             if (self.data[i].nunique()/self.data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
-                self.continuous.append(i)
+        for i in data.columns:
+             if (data[i].nunique()/data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
+                continuous.append(i)
              else:
-                self.categorical.append(i)
-        cn=self.data.drop(columns=self.categorical,axis=1)
+                categorical.append(i)
+        cn=data.drop(columns=categorical,axis=1)
         return sn.pairplot(cn,corner=True,kind="scatter")
         
     def _get_scatterplot(self,x,y,hue=None,style=None):
